/**
 *
 * This example shows how a client program can use the Java Beans that
 * are generated from an XML Schema or a DTD to create an XML instance document.
 *
 * To use this client program, generate the Java Beans for the PurchaseOrder.xsd
 * either using the WebSphere Studio Workbench or using the xsd2Java command. 
 *
 * For example, to use the xsd2Java.bat:
 *   xsd2Java -xsd PurchaseOrder.xsd -root PurchaseOrderType -dir outputDir
 *
 * Once you generated the Java Beans, you need to compile them. You can either
 * build within the Workbench, or set up your classpath to include all the jars.
 * An example setpath.bat file is provided in this directory to help you set 
 * up your classpath.
 * 
 * Please refer to the product documentation for step-by-step instructions.
 *
 */
import com.ibm.etools.xmlschema.beans.*;
import java.util.*;

public class PurchaseOrderSample
{
  purchaseOrderFactory iPurchaseOrderFactory;
  purchaseOrder iPurchaseOrder;
  
  public PurchaseOrderSample()
  {
  }
    
  /**
   * Create a PurchaseOrderType instance
   */
  void createpurchaseOrder()
  {
    // create the shipTo and billTo address
    iPurchaseOrder.setShipTo(createShipToUSAddress("shipTo"));
    iPurchaseOrder.setBillTo(createBillToUSAddress("billTo"));

    // Update the comment
    iPurchaseOrder.setComment("Hurry, my lawn is going wild");

    // create the items
    iPurchaseOrder.setItems(createItems("items"));

    // set the order date to today
    iPurchaseOrder.setOrderDate(new Date());
  }
   
  /**
   * Create the shipTo USAddress
   */
  USAddress createShipToUSAddress(String name)
  {
    USAddress shipToUSAddress = iPurchaseOrderFactory.createUSAddress(name);

    shipToUSAddress.setName("Alice Smith");
    shipToUSAddress.setStreet("123 Maple Street");
    shipToUSAddress.setCity("Mill Valley");
    shipToUSAddress.setState("CA");
    shipToUSAddress.setZip("90952");
    shipToUSAddress.setCountry("US");
    
    return shipToUSAddress;
  }
  
  /**
   * Create the billTo USAddress
   */
  USAddress createBillToUSAddress(String name)
  {
    USAddress billToUSAddress = iPurchaseOrderFactory.createUSAddress(name);

    billToUSAddress.setName("Robert Smith");
    billToUSAddress.setStreet("8 Oak Avenue");
    billToUSAddress.setCity("Old Town");
    billToUSAddress.setState("PA");
    billToUSAddress.setZip("95819");
    billToUSAddress.setCountry("US");

    return billToUSAddress;
  }
    
  /**
   * Create the two items
   */
  Items createItems(String name)
  {
    Items iItems = iPurchaseOrderFactory.createItems(name);

    iItems.setItem(0, createItem1("item"));
    iItems.setItem(1, createItem2("item"));

    return iItems;
  }
    
  /**
   * Create the first item - lawnmower
   */
  Items.item createItem1(String name)
  {
    Items.item iItem = iPurchaseOrderFactory.createItems_item(name);

    iItem.setProductName("Lawnmower");
    iItem.setQuantity(1);
    iItem.setUSPrice("148.95");

    iItem.setComment("Confirm this is electic");

    //
    // Create the partNum 
    //
    SKU iSKU = iPurchaseOrderFactory.createSKU("partNum");
    iSKU.updateElementValue("872-AA");
    iItem.setPartNum(iSKU);

    return iItem;
  }
  
  /**
   * Create the second item - baby monitor
   */
  Items.item createItem2(String name)
  {
    Items.item iItem = iPurchaseOrderFactory.createItems_item(name);

    iItem.setProductName("Baby Monitor");
    iItem.setQuantity(1);
    iItem.setUSPrice("39.98");
   
    iItem.setShipDate(new Date());

    //
    // Create the partNum 
    //
    SKU iSKU = iPurchaseOrderFactory.createSKU("partNum");
    iSKU.updateElementValue("926-AA");
    iItem.setPartNum(iSKU);

    return iItem;
  }
  
  /**
   * Print the Purchase Order
   */
  void printPurchaseOrder()
  {
    // Print ship to address
    System.out.println("Ship To Address:");
    printUSAddress(iPurchaseOrder.getShipTo());

    // Print bill to address
    System.out.println("\nBill To Address:");
    printUSAddress(iPurchaseOrder.getBillTo());

    // Print comment
    System.out.println("\ncomment: " + iPurchaseOrder.getComment());

    // Print each item
    printItems(iPurchaseOrder.getItems());

    // Print order date
    System.out.println("\norderDate: " + iPurchaseOrder.getOrderDate());
  }

  /**
   * Print a USAddress
   */
  void printUSAddress(USAddress iUSAddress)
  {
    System.out.println("  name:   " + iUSAddress.getName());
    System.out.println("  street: " + iUSAddress.getStreet());
    System.out.println("  city:   " + iUSAddress.getCity());
    System.out.println("  state:  " + iUSAddress.getState());
    System.out.println("  zip:    " + iUSAddress.getZip());
    System.out.println("  country:" + iUSAddress.getCountry());
  }

  /**
   * Print all the items
   */
  void printItems(Items iItems)
  {
    System.out.println("\nItem 1: ");
    printitem(iItems.getItem(0));

    System.out.println("\nItem 2: ");
    printitem(iItems.getItem(1));
  }

  /**
   * Print an item
   */
  void printitem(Items.item iItem)
  {
    System.out.println("   productName: " + iItem.getProductName());
    System.out.println("   quantity:    " + iItem.getQuantity());
    System.out.println("   USPrice:     " + iItem.getUSPrice());

    String comment = iItem.getComment();
    if (comment != null) 
    {
      System.out.println("   comment:     " + comment);
    }

    Date date = iItem.getShipDate();
    if (date != null) 
    {
      System.out.println("   shipDate:    " + date);
    }
    
    SKU iSku = iItem.getPartNum();
    System.out.println("   partNum:     " + iSku.getElementValue());
  }
  
  /**
   * Create a new instance document
   */
  void createNewInstance(String filename)
  {
    iPurchaseOrderFactory = new purchaseOrderFactory();
    iPurchaseOrderFactory.setPackageName("");

    // include schemaLocation hint for validation
    iPurchaseOrderFactory.setXSDFileName("PurchaseOrder.xsd");
    iPurchaseOrderFactory.setNamespaceURI("http://www.ibm.com");
    
    // encoding for output document
    iPurchaseOrderFactory.setEncoding("UTF8");
    
    // encoding tag for xml declaration
    iPurchaseOrderFactory.setEncodingTag("UTF-8");

    // Create the root element in the document
    iPurchaseOrder = (purchaseOrder) iPurchaseOrderFactory.createRoot("po:purchaseOrder");
    createpurchaseOrder();
    
    iPurchaseOrderFactory.save(filename);
  }
  
  /**
   * Load an existing instance document
   */
  void loadExistingInstance(String filename)
  {
    iPurchaseOrderFactory = new purchaseOrderFactory();
    iPurchaseOrderFactory.setPackageName("");
    
    // Load the document
    iPurchaseOrder = (purchaseOrder) iPurchaseOrderFactory.loadDocument(filename);
    printPurchaseOrder();
  }
  
  /**
   * This sample program shows how to use the Java beans
   * that are generated for the PurchaseOrder.xsd sample
   */
  public static void main(String args[])
  {
    PurchaseOrderSample poSample = new PurchaseOrderSample();

    poSample.createNewInstance("sample.xml");
    poSample.loadExistingInstance("sample.xml");
  }
}

