package com.ibm.b2b.examples.hospital;  

import java.io.*;
import proxy.response.generated.*;
import org.w3c.dom.*;
import proxy.soap.InsuranceServiceBeanProxy;

// This servlet handles requests from the client for Insurance claims.
// This servlet will  call Insurance proxy to make the claim and then pass the response
// to the user via a JSP.
public class ClaimServlet extends javax.servlet.http.HttpServlet implements javax.servlet.SingleThreadModel 
{

  /**
   * Process incoming HTTP GET requests 
   * 
   *  @param request Object that encapsulates the request to the servlet 
   * @param response Object that encapsulates the response from the servlet
   */
  public void doGet(javax.servlet.http.HttpServletRequest request, javax.servlet.http.HttpServletResponse response) throws javax.servlet.ServletException, java.io.IOException 
  {
    performTask(request, response);
  }

  /**
   * Process incoming HTTP POST requests 
   * 
   * @param request Object that encapsulates the request to the servlet 
   * @param response Object that encapsulates the response from the servlet
   */
  public void doPost(javax.servlet.http.HttpServletRequest request, javax.servlet.http.HttpServletResponse response) throws javax.servlet.ServletException, java.io.IOException 
  {
    performTask(request, response);
  }

  /**
   * This method retrieves parameters from the incoming request.
   */
  public String getParameter(javax.servlet.http.HttpServletRequest request, String parameterName )
  {
    String[] parameterValues = null;
    String paramValue = null;

    // Get the parameter from the request object if necessary.
    parameterValues = request.getParameterValues(parameterName);

    if (parameterValues != null)
	 paramValue = parameterValues[0];
    else
	 paramValue = "";

    return paramValue;
  }

  /**
   * Returns the servlet info string.
   */
  public String getServletInfo() 
  {
    return super.getServletInfo();
  }

  /**
   * Initializes the servlet.
   */
  public void init() {}

  /**
   * Process incoming requests for information
   * 
   * @param request Object that encapsulates the request to the servlet 
   * @param response Object that encapsulates the response from the servlet
   */
 
  public void performTask(javax.servlet.http.HttpServletRequest request, javax.servlet.http.HttpServletResponse response) 
  {
    javax.servlet.ServletContext    sc;
    javax.servlet.RequestDispatcher rd;
	
    try
    {		
	  sc = getServletContext();

      System.out.println( "In claim app" );
        		
      // Get the patient information from the form data received.				
      PatientInfo patientInfo = new PatientInfo();
      savePatientInfo( request, patientInfo );

      // Create a proxy to the insurance service.		
      InsuranceServiceBeanProxy service = new InsuranceServiceBeanProxy();

      // Call the insurance service with the input parameters collected from the user.
      // This call will return an XML DOM tree.
      Element responseElem = service.processClaim( patientInfo.getPatientName(),
                                                   patientInfo.getClaimAmount(),
                                                   patientInfo.getServiceDate(),
                                                   patientInfo.getServiceType(),
                                                   patientInfo.getSsn() ); 
      
      // Create a factory that will create a fluffed up a response object.                                                                        
      responseFactory factory = new responseFactory();
  	  factory.setPackageName( "proxy.response.generated");
  	    
      // Create a response object.
      response respInfo = (response)(factory.loadDocument( "response", responseElem ) ); 
		              
      // Store the original request information as well as the response from
      // the insurance service in the session data.
 	  request.getSession().setAttribute("patientData", patientInfo);
 	  request.getSession().setAttribute("responseData", respInfo );
		
      // Forward this request to a JSP.  The JSP will read the patient and response
      // information that we put into the session and create a nice HTML document for
      // the user.
	  rd = sc.getRequestDispatcher("/jsp/statuswindow.jsp?pageKind=Ok");
	  rd.forward(request, response);
    }
    catch(Throwable theException)
    {
      theException.printStackTrace();
    }
  }

  // Save the patient information from the form sent to this
  // servlet.
  public void savePatientInfo( javax.servlet.http.HttpServletRequest request,
                               PatientInfo                           patientInfo ) 
  {
    try
    {
	  String patientName       = getParameter( request, "Patientname" );
	  String amountReceived    = getParameter( request, "Amountreceived" );
	  String claimFileDate     = getParameter( request, "Claimfiledate" );
	  String claimReceivedDate = getParameter( request, "Claimreceivedate" );
	  String claimReceived     = getParameter( request, "Claimreceived" );
	  String insurance         = getParameter( request, "Insurance" );
	  String serviceDate       = getParameter( request, "Servicedate" );
	  String serviceType       = getParameter( request, "Servicetype" );
	  String ssn               = getParameter( request, "Ssn" );
	  String visitText         = getParameter( request, "visit_text" );
	  String doctorName        = getParameter( request, "doctor" );
	  String visitCost         = getParameter( request, "cost" );
	  String acctNum           = getParameter( request, "Acctnum" );
		
	  // We don't need all of the parameter that have been sent of the http request.
	  // We will store the ones that we need.
	  patientInfo.setPatientName( patientName );
	  patientInfo.setClaimAmount( visitCost );
	  patientInfo.setServiceDate( serviceDate );
	  patientInfo.setServiceType( serviceType );
	  patientInfo.setSsn( ssn );
    }
    catch(Throwable theException)
    {
	  System.err.println( "Something bad happened saving info" );
	  theException.printStackTrace();
    }	
  }
}

