package com.ibm.b2b.examples.hospital;


import org.tempuri.patientproj.patientgroup.patient.dadx.xsd.FindPatientResultElement;
import org.w3c.dom.*;
import proxy.soap.patientProxy;

/**
 * This class will response to client requests for patient information.  It will delegate
 * the request to a DADX web service which will return the requested patient account 
 * information.
 */
public class HospitalServlet extends javax.servlet.http.HttpServlet implements javax.servlet.SingleThreadModel 
{

  /**
   * Process incoming HTTP GET requests 
   * 
   * @param request Object that encapsulates the request to the servlet 
   * @param response Object that encapsulates the response from the servlet
   */
  public void doGet(javax.servlet.http.HttpServletRequest request, javax.servlet.http.HttpServletResponse response) throws javax.servlet.ServletException, java.io.IOException 
  {
    performTask(request, response);
  }

  /**
   * Process incoming HTTP POST requests 
   * 
   * @param request Object that encapsulates the request to the servlet 
   * @param response Object that encapsulates the response from the servlet
   */
  public void doPost(javax.servlet.http.HttpServletRequest request, javax.servlet.http.HttpServletResponse response) throws javax.servlet.ServletException, java.io.IOException 
  {
    performTask(request, response);
  }

  /**
   * Returns the requested parameter 
   * 
   * @param request Object that encapsulates the request to the servlet 
   * @param parameterName The name of the parameter value to return 
   * @param checkRequestParameters when true, the request parameters are searched 
   * @param checkInitParameters when true, the servlet init parameters are searched 
   * @param isParameterRequired when true, an exception is thrown when the parameter cannot be found 
   * @param defaultValue The default value to return when the parameter is not found 
   * @return The parameter value 
   * @exception java.lang.Exception Thrown when the parameter is not found 
   */
  public String getParameter(javax.servlet.http.HttpServletRequest request, String parameterName, boolean checkRequestParameters, boolean checkInitParameters, boolean isParameterRequired, String defaultValue) throws Exception 
  {
    String[] parameterValues = null;
    String paramValue = null;

    // Get the parameter from the request object if necessary.
    if (checkRequestParameters)
    {
	parameterValues = request.getParameterValues(parameterName);
	if (parameterValues != null)
        paramValue = parameterValues[0];
    }

    // Get the parameter from the servlet init parameters if
    // it was not in the request parameter.
    if ( (checkInitParameters) && (paramValue == null) )
	paramValue = getServletConfig().getInitParameter(parameterName);

    // Throw an exception if the parameter was not found and it was required.
    // The exception will be caught by error processing and can be
    // displayed in the error page.
    if ( (isParameterRequired) && (paramValue == null) )
      throw new Exception("Parameter " + parameterName + " was not specified.");

    // Set the return to the default value if the parameter was not found
    if (paramValue == null)
	paramValue = defaultValue;

    return paramValue;
  }

  /**
   * Returns the servlet info string.
   */
  public String getServletInfo() 
  {
    return super.getServletInfo();
  }

  /**
   * Initializes the servlet.
   */
  public void init() {}

  /**
   * Process incoming requests for information
   * 
   * @param request Object that encapsulates the request to the servlet 
   * @param response Object that encapsulates the response from the servlet
   */
  public void performTask(javax.servlet.http.HttpServletRequest request, javax.servlet.http.HttpServletResponse response) 
  {
    javax.servlet.ServletContext sc;
    javax.servlet.RequestDispatcher rd;

    try
    {
 	  System.out.println( "Start hospital servlet task" );
	  String acctNum = getParameter(request, "init_argAcctno", true, true, true, null);
	  int    acctNumInt = 0;
	  
	  try
	  {
	    acctNumInt = Integer.parseInt( acctNum );
	  }
	  catch( NumberFormatException exc )
	  {
	  	// Ignore request if this is not a valid number.
	  	acctNum = "";
	  }
		
	  patientProxy patientProxy = new patientProxy(); 

	  if( !acctNum.equals( "" ) )
	  {	
	    sc = getServletContext();
		  	
  	    // Call the proxy and store the result.
	    FindPatientResultElement patient = patientProxy.findPatient( acctNumInt );
		    		    
		// Find out how many patient rows were found.  In our case there should only
		// be one row.    		    
		FindPatientResultElement.FindPatientRowElementLocal[] rows = patient.getFindPatientRow();
		  
        System.out.println( "patient rows =" + rows.length );
       
	    String pageKind = null;
		  
	    if( rows.length == 0 )
	    {
	      // Account request does not exist.
	      System.out.println( "Acct # not found." );
	      request.getSession().setAttribute( "acctnum", acctNum );
	      pageKind = "pageKind=noPatient";
	    }
	    else
	    {
          // The account was found. We will save the row of the patient found
          // in a session attribute.  This object will be used by the PatientInfo.jsp
          // file to display the patient information.
 	      request.getSession().setAttribute("patientInfo", rows[0]);
	      pageKind = "pageKind=noError";
	    }
		  
	    rd = sc.getRequestDispatcher("/jsp/PatientInfo.jsp?" + pageKind );
	    rd.forward(request, response);
   	  }
    }
    catch(Throwable theException)
    {
      // uncomment the following line when unexpected exceptions
	  // are occuring to aid in debugging the problem.
	  theException.printStackTrace();
    }
  }
}
