package com.ibm.b2b.examples.insurance;

import com.ibm.etools.sqltoxml.*;
import java.io.*;
import java.util.*;
import org.w3c.dom.*;

import javax.xml.transform.*;
import javax.xml.transform.dom.*;
import javax.xml.parsers.*;
import org.xml.sax.*;


// This insurance bean processes claim requests from hospitals.
// This bean will be deployed as a web service for hospitals
// to access.
public class InsuranceServiceBean 
{
  private static final String policyName   = "FindHealthPolicy";
  private static final String responseName = "Response";
  
  public Element processClaim( String patientName,
                               String chargeAmount,
                               String serviceDate,
                               String serviceType,
                               String ssn )
  {    
    Element returnResult    = null;
	
    System.out.println( "In insurance service bean" );

    // Get the health policy for this customer.
    try
    {
      // Locate the FindHealthPolicy.xst file.  This file contains the SQL query
      // statement.
      CharArrayWriter charWriter = new CharArrayWriter();
      PrintWriter     writer     = new PrintWriter( charWriter );	  
      QueryProperties props      = new QueryProperties();
      InputStream     xstStream  = this.getClass().getResourceAsStream( "/query_info/FindHealthPolicy.xst" );
      props.load( xstStream ); 
	
      // Perform the query and generate an XML stream as output.  Note: this
      // XML stream will be stored in the charWriter buffer which we will switch
      // to be an XML input stream below.
      SQLToXML sqltoxml = new SQLToXML( props );
      sqltoxml.setParameters( "'"+ssn+"'" );
      sqltoxml.setXMLWriter( writer );
      sqltoxml.execute();	  
      writer.flush();
	  
      // Create a reader for the XML generated above for the 
      // transformer code below.
      CharArrayReader charReader = new CharArrayReader( charWriter.toCharArray() );
	  
      // Now transform the XML generated by the query to the XML
      // format required for transmission to the hospital app.  

      // Create the transformation factory.
      TransformerFactory     transFactory = TransformerFactory.newInstance();
      DocumentBuilderFactory buildFactory = DocumentBuilderFactory.newInstance();
	  
      buildFactory.setNamespaceAware( true );

      // Create a stream for the XSL file.  This file contains the template of how
      // the input XML stream should be transformed into the output XML stream. 	  	  
      InputStream     xslStream    = this.getClass().getResourceAsStream( "/query_info/Response.xsl" );
      DocumentBuilder builder      = buildFactory.newDocumentBuilder();
      Document        xslDoc       = builder.parse( xslStream );
      DOMSource       xslSource    = new DOMSource( xslDoc );
	  
      xslSource.setSystemId( "Response.xsl" );
	
      // Create transformation code that uses the XSL document.  
      Transformer   transformer  = transFactory.newTransformer( xslSource );
	
      // Create the xmlSource document from the XML stream create above.  
      InputSource   xmlInput     = new InputSource( charReader );
      Document      xmlDoc       = builder.parse( xmlInput );
      DOMSource     xmlSource    = new DOMSource( xmlDoc );

      // The xmlResult object will contain the results of the transformation.
      DOMResult     xmlResult    = new DOMResult();
      xmlSource.setSystemId( "generatedXML.xml" );

      // Perform the transformation.  The results are stored in xmlResult.
      transformer.transform( xmlSource, xmlResult );              
      returnResult = ((Document)(xmlResult.getNode())).getDocumentElement();
    }
    catch( Throwable exc )
    {	
      System.out.println( "problem with sqltoxml:" + exc.getMessage() );	
      exc.printStackTrace();
    }
				
    // Send the response XML back to the hospital.	
    return returnResult;
  }                                                    
}
